import React, { useEffect, useState } from "react";
import cockpit from "cockpit";
// eslint-disable-next-line camelcase
import { install_dialog } from "cockpit-components-install-dialog.jsx";
import {
    Alert,
    Card,
    CardBody,
    CardHeader
} from "@patternfly/react-core";
import { useInstallationStatus } from "./package-utils.js";
import { useNotifications } from "../app.components.jsx";
import { Button } from "@patternfly/react-core/dist/esm/components/Button";
import { installEventEmitter } from "../emitters.js";
import { RevPiConfigService } from "../revpi-config/RevPiConfigService.js";

const _ = cockpit.gettext;

export function InstallFeatureCard ({ featureName, packagesName, children }) {
    const [isInstalled, handleInstallationComplete] =
    useInstallationStatus(packagesName);
    const [globalIsInstalling, setGlobalIsInstalling] = useState(false);
    const { addNotification } = useNotifications();
    const notificationTitle = _("Installation successful");
    const notificationText = _("$0 successfully installed");

    useEffect(() => {
        const handleInstallationStart = (event) => {
            setGlobalIsInstalling(true);
        };
        const handleInstallationFinish = (event) => {
            setGlobalIsInstalling(false);
        };

        // Add the event listener
        installEventEmitter.addEventListener(
            installEventEmitter.events.start,
            handleInstallationStart
        );
        installEventEmitter.addEventListener(
            installEventEmitter.events.finish,
            handleInstallationFinish
        );

        // Cleanup the event listener on component unmount
        return () => {
            installEventEmitter.removeEventListener(
                installEventEmitter.events.start,
                handleInstallationStart
            );
            installEventEmitter.removeEventListener(
                installEventEmitter.events.finish,
                handleInstallationFinish
            );
        };
    }, []);

    const handleInstallClick = async () => {
        installEventEmitter.dispatchEvent(installEventEmitter.events.start);
        try {
            await install_dialog(packagesName);
            handleInstallationComplete();
            addNotification(notificationTitle, cockpit.format(notificationText, featureName));
            RevPiConfigService.getInstance().refresh();
        } catch (error) {
        } finally {
            installEventEmitter.dispatchEvent(installEventEmitter.events.finish);
        }
    };

    if (isInstalled) return <>{children}</>;

    return (
        <Card>
            <CardHeader>
                <Alert
                    variant='info'
                    isInline
                    isPlain
                    title={cockpit.format(_("$0 is not installed."), featureName)}
                />
            </CardHeader>
            <CardBody>
                <Button onClick={handleInstallClick} isDisabled={globalIsInstalling}>
                    {cockpit.format(_("Install $0"), featureName)}
                </Button>
            </CardBody>
        </Card>
    );
}
