import { Card, CardBody, CardTitle, Grid, GridItem } from "@patternfly/react-core";
import React from "react";
import cockpit from "cockpit";
import { NodeRedLink } from "./nodered-link/NodeRedLinkButton.jsx";
import { RevPiHelpText } from "../common.components.jsx";
import { InstallFeatureCard } from "./InstallFeature.jsx";

const _ = cockpit.gettext;

export function NodeRedCard ({ getRevpiSwitch, item }) {
    const cardTitle = _("Node-RED");
    const nodeRedPackageName = ["revpi-nodered", "revpi-nodered-proxy-apache", "noderedrevpinodes-server"];
    const nodeRedFeatureName = "Node-RED";
    const { isEnabled } = item;

    return (
        <Card isFullHeight name='node-red'>
            <CardTitle>
                {cardTitle}
                <RevPiHelpText title={cardTitle}>
                    {_("Node-RED is a graphical programming tool for wiring together hardware devices, APIs and online services.")}
                </RevPiHelpText>
            </CardTitle>
            <CardBody>
                <Grid hasGutter>
                    <GridItem span={12}>
                        <InstallFeatureCard packagesName={nodeRedPackageName} featureName={nodeRedFeatureName}>
                            <NodeRedLink isEnabled={isEnabled} />
                        </InstallFeatureCard>
                    </GridItem>
                    <GridItem span={12}>
                        {getRevpiSwitch("nodered")}
                    </GridItem>
                    <GridItem span={12}>
                        {getRevpiSwitch("noderedrevpinodes-server")}
                    </GridItem>
                </Grid>
            </CardBody>
        </Card>
    );
}
