import { useEffect, useState } from "react";
import cockpit from "cockpit";

/**
 *
 * @param packageName
 * @returns {Promise<boolean>}
 */
export async function isPackageInstalled (packageName) {
    try {
        await cockpit.spawn([
            "bash",
            "-c",
            `dpkg -l | grep -w '^ii  ${packageName}' `
        ]);
        return true;
    } catch (error) {
        console.info(`Info: ${packageName} is not installed.`, error);
        return false;
    }
}

/**
 *
 * @param packageNames
 * @returns {(boolean|(function(): Promise<void>)|*)[]}
 */
export function useInstallationStatus (packageNames) {
    const [isInstalled, setIsInstalled] = useState(false);
    useEffect(() => {
        async function checkInstallation () {
            let installed = true;
            for (const packageName of packageNames) {
                const isPkgInstalled = await isPackageInstalled(packageName);
                installed = installed && isPkgInstalled;
                if (!installed) break;
            }

            setIsInstalled(installed);
        }

        checkInstallation();
    // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []); // Empty dependency array ensures this runs only once on mount
    const handleInstallationComplete = async () => {
        let installed = true;
        for (const packageName of packageNames) {
            const isPkgInstalled = await isPackageInstalled(packageName);
            installed = installed && isPkgInstalled;
            if (!installed) break;
        }
        setIsInstalled(installed);
    };
    return [isInstalled, handleInstallationComplete];
}
